/*
 * Copyright (c) 2003, 2004 Henri Sivonen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package fi.iki.hsivonen.template.servlet;
import java.util.Date;
import java.util.Iterator;
import java.util.Set;

import javax.servlet.http.HttpServletResponse;

import fi.iki.hsivonen.template.Dependencies;
import fi.iki.hsivonen.template.Response;

/**
 *
 * @author  hsivonen
 */
public class ResponseImpl implements Response {
    
    private HttpServletResponse response;
    private String hostName;
    
    /** Creates a new instance of ResponseImpl */
    public ResponseImpl(HttpServletResponse response, String hostName) {
        this.response = response;
        this.hostName = hostName;
    }
    
    public void setLastModified(Date date) {
        this.response.setDateHeader("Last-Modified", date.getTime());
    }
    
    public java.io.OutputStream getOutputStream() throws java.io.IOException {
        return this.response.getOutputStream();
    }
    
    public void setContentLength(int length) {
        this.response.setContentLength(length);
    }
    
    public void setContentType(String type) {
        this.response.setContentType(type);
        long expiryDelta = Long.parseLong(System.getProperty("fi.iki.hsivonen.webcms.expiry." + this.hostName + '.' + type, System.getProperty("fi.iki.hsivonen.webcms.expiry.default." + type, "0")));
        this.response.setDateHeader("Expires", System.currentTimeMillis() + expiryDelta * 1000L);
    }
    
    public void setDependencies(Dependencies dependencies) {
        Date date = dependencies.getExpiryDate();
        if(date != null) {
            this.response.setDateHeader("X-Cache-Expires", date.getTime());
        }
        Set keys = dependencies.getKeys();
        if(keys != null) {
            Iterator iter = keys.iterator();
            while(iter.hasNext()) {
                this.response.addHeader("X-Cache-Dependencies", iter.next().toString());
            }
        }
    }
    
}
