/*
 * Copyright (c) 2003, 2004 Henri Sivonen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package fi.iki.hsivonen.template.servlet;
import java.io.IOException;
import java.net.URL;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import fi.iki.hsivonen.template.DataSourceException;
import fi.iki.hsivonen.template.RedirectException;
import fi.iki.hsivonen.template.ResourceNotFoundException;
import fi.iki.hsivonen.template.TemplateEngine;
import fi.iki.hsivonen.template.TemplateException;

/**
 *
 * @author  hsivonen
 */
public class TemplateEngineServlet extends HttpServlet {
    
    private DataSourceSource dss;
    
    /** Creates a new instance of TemplateEngineServlet */
    public TemplateEngineServlet() {
        
    }
    
    protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        try {
            URL url = new URL(request.getRequestURL().toString()); // XXX query string
            if(url.getPort() == url.getDefaultPort()) {
            	url = new URL(url.getProtocol(), url.getHost(), -1, url.getFile());
            }
            TemplateEngine te = new TemplateEngine(this.dss.dataSource());
            te.respond(url, new ResponseImpl(response, url.getHost()));
        } catch(ResourceNotFoundException e) {
            response.sendError(HttpServletResponse.SC_NOT_FOUND);
        } catch(RedirectException re) {
            response.sendRedirect(re.getTarget().toString());
            // permanent redirects not implemented
        } catch(TemplateException te) {
            throw new ServletException(te);
        } catch(DataSourceException dse) {
            throw new ServletException(dse);
        }
    }
   
    public void init() throws ServletException {
        try {
            this.dss = (DataSourceSource) Class
                    .forName(
                            System
                                    .getProperty(
                                            "fi.iki.hsivonen.template.servlet.datasourcesource",
                                            "fi.iki.hsivonen.webcms.application.URLDispatcherFactory"))
                    .newInstance();
        } catch (Exception e) {
            throw new ServletException(e);
        }
    }
    
    public String getServletInfo() {
        return "TemplateEngineServlet: an HTTP front end for TemplateEngine.";
    }
    
    public String getServletName() {
        return "TemplateEngineServlet";
    }
    
}
