/*
 * Copyright (c) 2003, 2004 Jussi Koskela
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package fi.iki.hsivonen.webcache.dependency;


public class DBSDependencyCollector extends DependencyCollector {

    /**
     * Registers a file dependency.
     * @param domain the id of the domain
     * @param file the id of the file
     */
    public void registerFile(String domain, String file) {
        CacheInvalidator.debug("Register file : " + domain + " " + file);
        registerKey(DBSKey.createDomainKey(domain));
        registerKey(DBSKey.createFileKey(domain, file));
    }

    /**
     * Registers an item dependency.
     * @param domain the id of the domain
     * @param app the id of the application instance
     * @param item the id of the item
     */
    public void registerItem(String domain, String app, String item) {
        registerKey(DBSKey.createDomainKey(domain));
        registerKey(DBSKey.createAppInstanceKey(domain, app));
        registerKey(DBSKey.createItemKey(domain, app, item));
    }

    /**
     * Registers an item set dependency.
     * @param domain the id of the domain
     * @param app the id of the application instance
     */
    public void registerItemSet(String domain, String app) {
        registerKey(DBSKey.createDomainKey(domain));
        registerKey(DBSKey.createAppInstanceKey(domain, app));
        registerKey(DBSKey.createItemSetKey(domain, app));
    }

    /**
     * Registers an application instance dependency.
     * @param domain the id of the domain
     * @param app the id of the application instance
     */
    public void registerAppInstance(String domain, String app) {
        registerKey(DBSKey.createDomainKey(domain));
        registerKey(DBSKey.createAppInstanceKey(domain, app));
    }

    /**
     * Registers an application instance set dependency.
     * @param domain the id of the domain
     */
    public void registerAppInstanceSet(String domain) {
        registerKey(DBSKey.createDomainKey(domain));
        registerKey(DBSKey.createAppInstanceSetKey(domain));
    }
}
