/*
 * Copyright (c) 2003, 2004 Jussi Koskela
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package fi.iki.hsivonen.webcache.dependency;

public class DBSKey {

    /**
     * Creates a dependency key for the given domain.
     * @param domain the id of the domain
     * @return the domain key
     */
    static String createDomainKey(String domain) {
        return getHashString("D:" + domain);
    }

    /**
     * Creates a dependency key for the given application instance.
     * @param domain the id of the domain
     * @param app the id of the application instance
     * @return the application instance key
     */    
    static String createAppInstanceKey(String domain, String app) {
        return getHashString("A:" + domain + ":" + app);
    }

    /**
     * Creates a dependency key for the given application instance set.
     * @param domain the id of the domain
     * @return the application instance set key
     */
    static String createAppInstanceSetKey(String domain) {
        return getHashString("B:" + domain);
    }

    /**
     * Creates a dependency key for the given file.
     * @param domain the id of the domain
     * @param file the id of the file
     * @return the file key
     */
    static String createFileKey(String domain, String file) {
        return getHashString("F:" + domain + ":" + file);
    }
    
    /**
     * Creates a dependency key for the given item.
     * @param domain the id of the domain
     * @param app the id of the application instance
     * @param item the id of the item
     * @return the item key
     */
    static String createItemKey(String domain, String app, String item) {
        return getHashString("I:" + domain + ":" + app + ":" + item);
    }
    
    /**
     * Creates a dependency key for the given item set.
     * @param domain the id of the domain
     * @param app the id of the application instance
     * @return the item set key
     */
    static String createItemSetKey(String domain, String app) {
        return getHashString("S:" + domain + ":" +app);
    }

    /**
     * Returns the hashed string presentation for the given string.
     * @param key the string to hash
     * @return the hash string
     */
    private static String getHashString(String key) {
        return Integer.toString(key.hashCode(), Character.MAX_RADIX);
    }
}
