/*
 * Copyright (c) 2003, 2004 Jussi Koskela
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package fi.iki.hsivonen.webcache.front;

import java.util.Date;
import java.util.TimerTask;

public class ExpireTimerTask extends TimerTask {

    /** back reference to cache handler */
    private CacheHandler cacheHandler;

    /** expiring file */
    private CachedFile cachedFile;

    /** date of expiration */
    private Date date;

    /**
     * Class constructor.
     * @param d the date of expiration
     * @param cf the expiring file
     * @param ch the cache handler
     */
    public ExpireTimerTask(Date d, CachedFile cf,
                           CacheHandler ch) {
        date = d;
        cachedFile = cf;
        cacheHandler = ch;
    }

    /**
     * Returns the expiration date.
     * @return the expiration data
     */
    Date getDate() {
        return date;
    }

    /**
     * Triggers the expiration.
     */
    public void run() {
        cacheHandler.onExpire(cachedFile);
    }
}
